==> mod_fast_bbs-0.0.1.tgz: mod_fast_bbs-0.0.1/include/ResponseWriter.h <==
/******************************************************************************
 * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: ResponseWriter.h 1526 2006-09-14 13:30:13Z svn $
 *****************************************************************************/

#ifndef RESPONSE_WRITER_H
#define RESPONSE_WRITER_H

#include "Environment.h"

#include <cstdlib>

#include "apr.h"

using namespace std;

/**
 * @brief レスポンスを書き出すクラス．
 */
class ResponseWriter
{
public:
    // 効率が落ちるので virtual にはしたくない
    void write(const char *str, apr_size_t length) throw();
    void write(const char *str) throw();
    void write(int i) throw();
private:
};

#endif

// Local Variables:
// mode: c++
// coding: utf-8-dos
// End:

==> mod_fast_bbs-1.0.5.tgz: mod_fast_bbs-1.0.5/include/ResponseWriter.h <==
/******************************************************************************
 * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: ResponseWriter.h 2317 2006-12-28 16:07:10Z svn $
 *****************************************************************************/

#ifndef RESPONSE_WRITER_H
#define RESPONSE_WRITER_H

#include "Environment.h"

#include <cstdlib>

#include "apr.h"


/**
 * @brief レスポンスを書き出すクラス．
 */
class ResponseWriter
{
public:
    // 効率が落ちるので virtual にはしたくない
    void write(const char *str, apr_size_t length);
    void write(const char *str);
    void write(int i);
private:
};

#endif

// Local Variables:
// mode: c++
// coding: utf-8-dos
// End:
